"use strict";

var _core = require("@babel/core");

var _ = _interopRequireDefault(require(".."));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function trim(str) {
  return str === null || str === void 0 ? void 0 : str.replace(/^\n+|\n+$/, '').replace(/\n+/g, '\n');
}

var babelAssign = function babelAssign() {
  var babelOptions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return function (expected, input) {
    var _transform;

    var transformed = (0, _core.transform)(input, babelOptions);
    expect(transformed === null || transformed === void 0 ? void 0 : transformed.code).toBeDefined();
    expect(_typeof(transformed === null || transformed === void 0 ? void 0 : transformed.code)).toEqual('string');
    expect(trim(transformed === null || transformed === void 0 ? void 0 : transformed.code)).toEqual(trim((_transform = (0, _core.transform)(expected, babelOptions)) === null || _transform === void 0 ? void 0 : _transform.code));
  };
};

var babelThrow = function babelThrow() {
  var babelOptions = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return function (input, msg) {
    expect(function () {
      return (0, _core.transform)(input, babelOptions);
    }).toThrow(msg);
  };
};

var simpleBabelAssign = babelAssign({
  plugins: [[_["default"], {
    extensions: ['.css', '.less', 'sass']
  }]]
});
var withES2015BabelAssign = babelAssign({
  presets: ['@babel/preset-env'],
  plugins: [[_["default"], {
    extensions: ['.less', 'sass']
  }]]
});
var simpleBabelThrow = babelThrow({
  plugins: [[_["default"], {
    extensions: ['.less', 'sass']
  }]]
});
test('should remove require call expression by extensions', function () {
  return simpleBabelAssign("\nrequire('babel');\n", "\nrequire('./index.css');\nrequire('./index.less');\nrequire('./index.sass');\nrequire('babel');\n");
});
test('should remove import call expression by extensions', function () {
  return simpleBabelAssign("\nimport './index.less';\nimport './index.css';\nimport * as babel from 'babel';", "\nimport * as babel from 'babel';\n");
});
test('should not process when remove require call expression in assignment expression', function () {
  return simpleBabelThrow("\nvar { a } = require('./index.less');\nrequire('babel');\n", './index.less should not be assigned to variable.');
});
test('should not process when remove import expression in default imports', function () {
  return simpleBabelThrow("\nimport myCss from './index.less';\nimport * as babel from 'babel';\n", './index.less should not be imported using default imports.');
});
test('should not process when remove import expression in named imports', function () {
  return simpleBabelThrow("\nimport { myCss } from './index.less';\nimport * as babel from 'babel';\n", './index.less should not be imported using named imports.');
});
test('should not process when remove import expression in namespace imports', function () {
  return simpleBabelThrow("\nimport * as myCss from './index.less';\nimport * as babel from 'babel';\n", './index.less should not be imported using namespace imports.');
});
test('should remove require call expression in other block', function () {
  return simpleBabelAssign("\n(function (){\n  require('./index.sass');\n  require('./index.less');\n  require('babel');\n})();\n", "\n(function (){\n  require('babel');\n})();\n");
});
test('should remove require call expression', function () {
  return withES2015BabelAssign("\n  require('./index.sass');\n  require('babel');\n", "\n  require('babel');\n");
});
test('should remove require call expression after import transformed', function () {
  return withES2015BabelAssign("\n  import './index.less';\n  import * as babel from 'babel';\n", "\n  import * as babel from 'babel';\n");
});