"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = _default;

var _path = require("path");

function _default() {
  function extFix(ext) {
    return ext.charAt(0) === '.' ? ext : ".".concat(ext);
  }

  return {
    visitor: {
      CallExpression: {
        enter: function enter(path, _ref) {
          var opts = _ref.opts;
          var extensionsInput = [].concat(opts.extensions || []);

          if (extensionsInput.length === 0) {
            return;
          }

          var extensions = extensionsInput.map(extFix);
          var callee = path.get('callee');

          if (callee.isIdentifier() && callee.equals('name', 'require')) {
            var arg = path.get('arguments')[0];

            if (arg && arg.isStringLiteral() && extensions.indexOf((0, _path.extname)(arg.node.value)) > -1) {
              if (path.parentPath.isVariableDeclarator()) {
                throw new Error("".concat(arg.node.value, " should not be assigned to variable."));
              } else {
                path.remove();
              }
            }
          }
        }
      },
      ImportDeclaration: {
        enter: function enter(path, _ref2) {
          var opts = _ref2.opts;
          var extensionsInput = [].concat(opts.extensions || []);

          if (extensionsInput.length === 0) {
            return;
          }

          var extensions = extensionsInput.map(extFix);

          if (extensions.indexOf((0, _path.extname)(path.node.source.value)) > -1) {
            var specifiers = path.get('specifiers');

            if (specifiers.length) {
              var specifier = specifiers[specifiers.length - 1];

              if (specifier.isImportDefaultSpecifier()) {
                throw new Error("".concat(path.node.source.value, " should not be imported using default imports."));
              }

              if (specifier.isImportSpecifier()) {
                throw new Error("".concat(path.node.source.value, " should not be imported using named imports."));
              }

              if (specifier.isImportNamespaceSpecifier()) {
                throw new Error("".concat(path.node.source.value, " should not be imported using namespace imports."));
              }
            }

            path.remove();
          }
        }
      }
    }
  };
}